@@ -3,13 +3,24 @@ function(cand.set, parm, modnames, c.hat=1, second.ord=TRUE, nobs=NULL){
 #check if class is appropriate
 #extract classes
   mod.class <- unlist(lapply(X=cand.set, FUN=class))
+  
 #check if all are identical
   check.class <- unique(mod.class)
   
   if(identical(check.class, "lm") || identical(check.class, c("glm", "lm")))  {
+    
+    #extract model formula for each model in cand.set
+    mod_formula<-lapply(cand.set, FUN=function(i) rownames(summary(i)$coefficients))
+  }
+  
+  if(identical(check.class, "lme")) {
+    mod_formula<-lapply(cand.set, FUN=function(i) labels(summary(i)$coefficients$fixed))
+  }
 
-mod_formula<-lapply(cand.set, FUN=function(i) rownames(summary(i)$coefficients))} #extract model formula for each model in cand.set
-if(identical(check.class, "lme")) {mod_formula<-lapply(cand.set, FUN=function(i) labels(summary(i)$coefficients$fixed))}
+  if(identical(check.class, c("multinom", "nnet"))) {
+    mod_formula<-lapply(cand.set, FUN=function(i) colnames(summary(i)$coefficients))
+  }
+  
 #setup matrix to indicate presence of parm in the model
 include <- matrix(NA, nrow=length(cand.set), ncol=1)
 
@@ -31,7 +42,9 @@ if (sum(include)==0) {stop("Parameter not found in any of the candidate models")
 new_table <- aictab(cand.set=cand.set, modnames=modnames, sort=FALSE, c.hat=c.hat, second.ord=second.ord, nobs=nobs)  
 
 #add a check to determine if the same number of models include and exlude parameter
-if (length(which(include==1)) != length(which(include!=1)) ) {stop("Importance values are only meaningful when the number of models with and without parameter are equal")}
+if (length(which(include==1)) != length(which(include!=1)) ) {
+  stop("Importance values are only meaningful when the number of models with and without parameter are equal")
+}
 
 w.plus <- sum(new_table[which(include==1), 6]) #select models including a given parameter
 w.minus <- 1 - w.plus
@@ -42,7 +55,7 @@ class(imp) <- c("importance", "list")
 return(imp)
 }
 
-#function for nicer printer of importance values
+#function for nicer printing of importance values
 print.importance <- function(x, digits=4, ...) {
   cat("\nImportance values of '", x$parm, "' :\n\n")
   cat("w+ (models including parameter): ", round(x$w.plus, digits=4), "\n")
